/**
 * Copyright 2004-2005 Fabrizio Giustina.
 *
 * Licensed under the Artistic License; you may not use this file
 * except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://maven-taglib.sourceforge.net/license.html
 *
 * THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
package net.sf.maventaglib;

import java.io.File;
import java.io.FilenameFilter;
import java.text.MessageFormat;
import java.util.Locale;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.project.MavenProject;
import org.apache.maven.reporting.AbstractMavenReport;
import org.apache.maven.reporting.MavenReport;
import org.apache.maven.reporting.MavenReportException;
import org.codehaus.doxia.site.renderer.SiteRenderer;

import com.sun.tlddoc.TLDDocGenerator;

/**
 * Generates taglibdoc documentation.
 * @goal taglibdoc
 * @author Fabrizio Giustina
 * @version $Id: TaglibdocMojo.java,v 1.7 2005/10/30 13:14:52 fgiust Exp $
 */
public class TaglibdocMojo
    extends AbstractMavenReport
    implements MavenReport
{

    /**
     * title for tlddoc generated documentation.
     * @parameter expression="${project.name} Tag library documentation"
     */
    private String title;

    /**
     * TldDoc output dir.
     * @parameter expression="${project.reporting.outputDirectory}/tlddoc"
     */
    private String tldDocDir;

    /**
     * tld directory path.
     * @parameter alias="taglib.src.dir" expression="${basedir}/src/main/resources/META-INF"
     */
    private String srcDir;

    /**
     * @see net.sf.maventaglib.AbstractTaglibMojo#execute()
     */
    public void execute()
        throws MojoExecutionException
    {
        File srcDirFile = new File( this.srcDir );
        File tldOutDir = new File( this.tldDocDir );
        getLog().info( MessageFormat.format( Messages.getString( "Taglib.generating.tlddoc" ), //$NON-NLS-1$
                                             new Object[] { srcDirFile.getAbsolutePath() } ) );
        TLDDocGenerator generator = new TLDDocGenerator();
        generator.setOutputDirectory( tldOutDir );
        generator.setQuiet( true );
        generator.setWindowTitle( this.title );

        if ( !srcDirFile.isDirectory() )
        {
            throw new MojoExecutionException( MessageFormat
                .format( Messages.getString( "Taglib.notadir" ), new Object[] { srcDirFile //$NON-NLS-1$
                    .getAbsolutePath() } ) );
        }

        File[] files = srcDirFile.listFiles();
        for ( int i = 0; i < files.length; i++ )
        {
            File current = files[i];
            if ( !current.isDirectory() && current.getName().toLowerCase().endsWith( ".tld" ) ) //$NON-NLS-1$
            {
                generator.addTLD( current );
            }
        }

        try
        {
            generator.generate();
        }
        catch ( Throwable e )
        {
            getLog().error( MessageFormat.format( Messages.getString( "Taglib.exception" ), //$NON-NLS-1$
                                                  new Object[] { e.getClass(), e.getMessage() } ), e );
        }
    }

    /**
     * @see org.apache.maven.reporting.AbstractMavenReport#getSiteRenderer()
     */
    protected SiteRenderer getSiteRenderer()
    {
        return null;
    }

    /**
     * @see org.apache.maven.reporting.AbstractMavenReport#getOutputDirectory()
     */
    protected String getOutputDirectory()
    {
        return null;
    }

    /**
     * @see org.apache.maven.reporting.AbstractMavenReport#getProject()
     */
    protected MavenProject getProject()
    {
        return null;
    }

    /**
     * @see org.apache.maven.reporting.AbstractMavenReport#executeReport(java.util.Locale)
     */
    protected void executeReport( Locale locale )
        throws MavenReportException
    {
        try
        {
            execute();
        }
        catch ( MojoExecutionException e )
        {
            throw new MavenReportException( e.getMessage(), e );
        }

    }

    /**
     * @see org.apache.maven.reporting.MavenReport#getOutputName()
     */
    public String getOutputName()
    {
        return "tlddoc/index"; //$NON-NLS-1$
    }

    /**
     * @see org.apache.maven.reporting.MavenReport#getName(java.util.Locale)
     */
    public String getName( Locale locale )
    {
        return Messages.getString( "Taglibdoc.name" ); //$NON-NLS-1$
    }

    /**
     * @see org.apache.maven.reporting.MavenReport#getDescription(java.util.Locale)
     */
    public String getDescription( Locale locale )
    {
        return Messages.getString( "Taglibdoc.description" ); //$NON-NLS-1$
    }

    /**
     * @see org.apache.maven.reporting.MavenReport#isExternalReport()
     */
    public boolean isExternalReport()
    {
        return true;
    }

    /**
     * @see org.apache.maven.reporting.AbstractMavenReport#canGenerateReport()
     */
    public boolean canGenerateReport()
    {

        File srcDirFile = new File( this.srcDir );
        if ( !srcDirFile.isDirectory() )
        {
            return false;
        }

        String[] files = srcDirFile.list( new FilenameFilter()
        {
            public boolean accept( File dir, String name )
            {
                String lcName = name.toLowerCase();
                return lcName.endsWith( "tld" ) || lcName.endsWith( "tag" ); //$NON-NLS-1$ //$NON-NLS-2$
            }
        } );

        return files.length > 0;
    }

}