/**
 * Copyright 2004-2005 Fabrizio Giustina.
 *
 * Licensed under the Artistic License; you may not use this file
 * except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://maven-taglib.sourceforge.net/license.html
 *
 * THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
package net.sf.maventaglib.checker;

import org.apache.commons.lang.builder.CompareToBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.lang.builder.ToStringStyle;

/**
 * Contains information about a tag.
 * @author Fabrizio Giustina
 * @version $Revision $ ($Author $)
 */
public class Tag
    implements Comparable
{

    private String name;

    private String tagClass;

    private String description;

    private String teiClass;

    private String bodycontent;

    private String example;

    private boolean deprecated;

    private TagAttribute[] attributes;

    private TagVariable[] variables;

    public String getName()
    {
        return this.name;
    }

    public void setName( String tagName )
    {
        this.name = tagName;
    }

    public TagAttribute[] getAttributes()
    {
        return this.attributes;
    }

    public void setAttributes( TagAttribute[] tagAttributes )
    {
        this.attributes = tagAttributes;
    }

    public String getTagClass()
    {
        return this.tagClass;
    }

    public void setTagClass( String className )
    {
        this.tagClass = className;
    }

    public String getTeiClass()
    {
        return this.teiClass;
    }

    public void setTeiClass( String className )
    {
        this.teiClass = className;
    }

    public String getDescription()
    {
        return this.description;
    }

    public void setDescription( String description )
    {
        this.description = description;
    }

    public String getBodycontent()
    {
        return this.bodycontent;
    }

    public void setBodycontent( String bodycontent )
    {
        this.bodycontent = bodycontent;
    }

    public String getExample()
    {
        return this.example;
    }

    public void setExample( String example )
    {
        this.example = example;
    }

    public TagVariable[] getVariables()
    {
        return this.variables;
    }

    public void setVariables( TagVariable[] variables )
    {
        this.variables = variables;
    }

    public boolean isDeprecated()
    {
        return this.deprecated;
    }

    public void setDeprecated( boolean deprecated )
    {
        this.deprecated = deprecated;
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
        return new ToStringBuilder( this, ToStringStyle.SIMPLE_STYLE ).append( "name", this.name ) //$NON-NLS-1$
            .append( "tagClass", this.tagClass ).append( "teiClass", this.teiClass ).append( "attributes", //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
                                                                                             this.attributes )
            .toString();
    }

    /**
     * @see java.lang.Comparable#compareTo(Object)
     */
    public int compareTo( Object object )
    {
        Tag myClass = (Tag) object;
        return new CompareToBuilder().append( this.deprecated, myClass.deprecated ).append( this.name, myClass.name )
            .toComparison();
    }

}